# -*- coding: utf-8 -*-

"""Magical auto-generation of KGE model CLIs."""

from .builders import build_cli_from_cls

__all__ = [
    "build_cli_from_cls",
]
